package edu.georgetown.gucs.tokenizers;

import java.util.Iterator;
import java.util.StringTokenizer;

import edu.georgetown.gucs.utility.Pair;

/**
 * Eliminates tokens from headers in the Enron data set
 * 
 * @author Clay Shields
 * @author Lindsay Neubauer
 * 
 */
public class EnronStripMailHeaderTokenizer extends Tokenizer {

  private static final long serialVersionUID = 2895675028020061928L;
  private boolean started;

  /**
   * Constructor to remove tokens from headers in the Enron data set
   */
  public EnronStripMailHeaderTokenizer() {
    this.started = false;
  }

  /**
   * Eliminates tokens from headers in the Enron data set
   */
  @Override
  public void tokenize(Iterator<String> iterator) {
    synchronized (this.tokenVector) {
      this.tokenVector.clear();
      while (iterator.hasNext()) {
        String token = iterator.next();
        if (token.contains("X-FileName")) {
          this.started = true;
        }
        if (this.started) {
          if (!token.contains("X-FileName")) {
            StringTokenizer st = new StringTokenizer(token);
            while (st.hasMoreTokens()) {
              String newToken = st.nextToken();
              this.tokenVector.add(newToken);
            }
          }
        }
      }
    }
  }

  /**
   * Eliminates tokens from headers in the Enron data set
   */
  @Override
  public void tokenize(Iterator<String> tokensIterator, Iterator<Pair<Integer, Integer>> positionsIterator) {
    synchronized (this.tokenVector) {
      synchronized (this.positions) {
        this.tokenVector.clear();
        this.positions.clear();
        while (tokensIterator.hasNext() && positionsIterator.hasNext()) {
          String token = tokensIterator.next();
          Pair<Integer, Integer> pos = positionsIterator.next();
          if (token.contains("X-FileName")) {
            this.started = true;
          }
          if (this.started) {
            if (!token.contains("X-FileName")) {
              StringTokenizer st = new StringTokenizer(token);
              while (st.hasMoreTokens()) {
                String newToken = st.nextToken().trim();
                this.tokenVector.add(newToken);
                this.positions.add(pos);
              }
            }
          }
        }
      }
    }
  }
}
