package edu.georgetown.gucs.tokenizers;

import java.util.Iterator;
import java.util.Locale;

import edu.georgetown.gucs.utility.Pair;

/**
 * Uses English stemming to change tokens into their root form
 * 
 * @author Clay Shields
 * @author Lindsay Neubauer
 * 
 */
public class PorterTokenizer extends Tokenizer {

  private static final long serialVersionUID = 1555744102819134473L;

  /**
   * Changes English language tokens into their root form
   */
  @Override
  public void tokenize(Iterator<String> iterator) {
    synchronized (this.tokenVector) {
      this.tokenVector.clear();
      Stemmer porterStemmer = new Stemmer();
      while (iterator.hasNext()) {
        String lc_token = iterator.next().trim().toLowerCase(Locale.ENGLISH);
        for (int i = 0; i < lc_token.length(); i++) {
          porterStemmer.add(lc_token.charAt(i));
        }
        porterStemmer.stem();
        String porterized = porterStemmer.toString();
        this.tokenVector.add(porterized);
      }
    }
  }

  /**
   * Changes English language tokens into their root form
   */
  @Override
  public void tokenize(Iterator<String> tokensIterator, Iterator<Pair<Integer, Integer>> positionsIterator) {
    synchronized (this.tokenVector) {
      synchronized (this.positions) {
        this.tokenVector.clear();
        this.positions.clear();
        Stemmer porterStemmer = new Stemmer();
        while (tokensIterator.hasNext() && positionsIterator.hasNext()) {
          String lc_token = tokensIterator.next().trim().toLowerCase(Locale.ENGLISH);
          Pair<Integer, Integer> pos = positionsIterator.next();
          for (int i = 0; i < lc_token.length(); i++) {
            porterStemmer.add(lc_token.charAt(i));
          }
          porterStemmer.stem();
          String porterized = porterStemmer.toString();
          this.tokenVector.add(porterized);
          this.positions.add(pos);
        }
      }
    }
  }
}
