package edu.georgetown.gucs.tokenizers;

import java.util.Iterator;
import java.util.regex.Pattern;

import edu.georgetown.gucs.utility.Pair;

/**
 * Eliminates tokens containing numbers
 * 
 * @author Clay Shields
 * @author Lindsay Neubauer
 * 
 */
public class RemoveTokensWithNumbersTokenizer extends Tokenizer {

  private static final long serialVersionUID = -5383824450221469920L;
  private static Pattern containsDigitPattern = Pattern.compile(".*\\d.*");

  /**
   * Eliminates tokens containing numbers
   */
  @Override
  public void tokenize(Iterator<String> iterator) {
    synchronized (this.tokenVector) {
      this.tokenVector.clear();
      while (iterator.hasNext()) {
        String token = iterator.next().trim();
        if (!containsDigitPattern.matcher(token).matches()) {
          this.tokenVector.add(token);
        }
      }
    }
  }

  /**
   * Eliminates tokens containing numbers
   */
  @Override
  public void tokenize(Iterator<String> tokensIterator, Iterator<Pair<Integer, Integer>> positionsIterator) {
    synchronized (this.tokenVector) {
      synchronized (this.positions) {
        this.tokenVector.clear();
        this.positions.clear();
        while (tokensIterator.hasNext() && positionsIterator.hasNext()) {
          String token = tokensIterator.next().trim();
          Pair<Integer, Integer> pos = positionsIterator.next();
          if (!containsDigitPattern.matcher(token).matches()) {
            this.tokenVector.add(token);
            this.positions.add(pos);
          }
        }
      }
    }
  }
}
