package edu.georgetown.gucs.utility;

import java.io.File;

/**
 * Thread for processing a file to add to a {@linkplain FileLister}
 * 
 * @author Lindsay Neubauer
 */
class FileListerWorker implements Runnable {

  private File currentFile;
  private FileLister fileLister;

  /**
   * Constructor that specifies a file to add to the existing fileLister
   * 
   * @param currentFile
   *          the file to add to the tail of the file queue
   * @param fileLister
   *          the fileLister to add the currentFile to
   */
  FileListerWorker(File currentFile, FileLister fileLister) {
    this.currentFile = currentFile;
    this.fileLister = fileLister;
  }

  /**
   * Adds the file to the existing fileLister
   */
  @Override
  public void run() {
    Global.monitor.writeToBuffer("FileListerWorker", "run_start", "file: " + this.currentFile.getPath()
        + " thread_id = " + Thread.currentThread().getName());
    this.fileLister.addFile(this.currentFile);
    this.fileLister.updateFileTypes(this.currentFile.getName());
    this.fileLister.putFile(this.currentFile);
    Global.monitor.writeToBuffer("FileListerWorker", "run_end", "file: " + this.currentFile.getName()
      + " thread_id = " + Thread.currentThread().getName());
  }
}
