package sdtext;

/**
 * Provides the different manglers available within SDText (Similarity Digest Text)
 * 
 * @author Lindsay Neubauer
 * 
 */
public enum ManglerEnum {

  /**
   * Disables all other manglers (must be in own manglers list)
   */
  Null("Null", "Disables all other manglers (must be in own manglers list)"),

  /**
   * Delete any token with a given percent chance
   */
  DeleteToken("DeleteToken", "Delete any token with a given percent chance"),

  /**
   * Delete any single character with a given percent chance
   */
  DeleteCharacter("DeleteCharacter", "Delete any single character with a given percent chance"),

  /**
   * Delete any instance of white space with a given percent chance
   */
  DeleteWhitespace("DeleteWhitespace", "Delete any instance of white space with a given percent chance"),

  /**
   * Change a character to some random ASCII lower case letter or number with given percent chance
   */
  ChangeCharacter("ChangeCharacter",
      "Change a character to some random ASCII lower case letter or number with given percent chance"),

  /**
   * Change a token to a random token from the Dictionary with given percent chance
   */
  ChangeToken("ChangeToken", "Change a token to a random token from the Dictionary with given percent chance"),

  /**
   * Insert white space randomly inside a token with given percent chance
   */
  SplitToken("SplitToken", "Insert white space randomly inside a token with given percent chance"),

  /**
   * Change a character to punctuation with given percent chance
   */
  ChangeToPunctuation("ChangeToPunctuation", "Change a character to punctuation with given percent chance"),

  /**
   * Deletes a contiguous number of tokens equal to given percent
   */
  DeleteSection("DeleteSection", "Deletes a contiguous number of tokens equal to given percent"),

  /**
   * Deletes a contiguous number of tokens equal to given percent from the head of the file
   */
  DeleteHead("DeleteHead", "Deletes a contiguous number of tokens equal to given percent from the head of the file"),

  /**
   * Deletes a contiguous number of tokens equal to given percent from the tail of the file
   */
  DeleteTail("DeleteTail", "Deletes a contiguous number of tokens equal to given percent from the tail of the file"),

  /**
   * Uses Classifier4J to create a document summary of 100-percent % size
   */
  SummaryReduce("SummaryReduce", "Uses Classifier4J to create a document summary of 100-percent % size");

  final String name;
  final String description;

  /**
   * Stores information about each tokenizer
   * 
   * @param name
   *          the string name of the mangler
   * @param description
   *          the string description of the mangler
   */
  ManglerEnum(String name, String description) {
    this.name = name;
    this.description = description;
  }
}
