package sdtext;

/**
 * Provides the different matchers available within SDText (Similarity Digest Text)
 * 
 * @author Lindsay Neubauer
 * 
 */
public enum MatcherEnum {

  /**
   * Provides a score based on a cosine similarity match to be used with a BitVectorFingerprinter
   */
  CosineSimilarityFingerprintMatcher("CosineSimilarityFingerprintMatcher"),

  /**
   * Determines if two fingerprints' documents are the same; uses a BitVectorFingerprinter
   */
  ExactFingerprintMatcher("ExactFingerprintMatcher"),

  /**
   * Determines if two fingerprints match based on their HashFingerprinter hash values
   */
  HashFingerprintMatcher("HashFingerprintMatcher"),

  /**
   * Provides a score to base a similarity match using a BitVectorFingerprinter
   */
  SimpleScoreFingerprintMatcher("SimpleScoreFingerprintMatcher");

  final String name;

  /**
   * Stores information about each matcher
   * 
   * @param name
   *          the string name of the matcher
   */
  MatcherEnum(String name) {
    this.name = name;
  }
}